MFLI
====

.. autoclass:: zhinst.qcodes.MFLI
    :show-inheritance:
    :members:


Data Acquisition Module for MFLI
--------------------------------

.. autoclass:: zhinst.qcodes.mfli.DAQ
    :show-inheritance:
    :members:



Sweeper Module for MFLI
-----------------------

.. autoclass:: zhinst.qcodes.mfli.Sweeper
    :show-inheritance:
    :members: